/***************************************************************************
                          job_computecdromid.h  -  description
                             -------------------
    begin                : Thu May 31 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_COMPUTECDROMID_H
#define JOB_COMPUTECDROMID_H

#include "prokyon.h"

#include "jobbase.h"

#include "lvi_cddrive.h"

class Job_ComputeCDROMID : public JobBase  {
public:
    Job_ComputeCDROMID(LVI_CDDrive *_drive);

    int type() {
        return JOB_COMPUTE_CDROM_ID;
    }

    void run();

    ~Job_ComputeCDROMID();

private:
    LVI_CDDrive *drive;

    unsigned CRC32(QString);
};

#endif
